//
// XMR.C [XMODEM Receive]
//
// Requires XYDRV [ver 2.3.5 or above]
//

#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "wsc.h"
#include "xydrv.h"
#include "sayerror.h"

#define NAK  0x15
#define XMODEM  0

#define DEBUG_OFF  0
#define DEBUG_LOW  1
#define DEBUG_HIGH 2

// set debug level below

int DebugLevel = DEBUG_OFF;

char Temp[81];

int RunXY(int Port)
{int Code;
 int Packet;
 int LastPacket;
 LastPacket = 0;
 while(1)
   {// run the driver
    Code = xyDriver(Port);
    // any messages from xyDriver ?
    while(xyGetMessage(Port,(LPSTR)Temp,80)>0) printf("%s\n",Temp);
    if(Code == XY_IDLE) return XY_IDLE;
    else if(DebugLevel==DEBUG_OFF)
      {// xyDriver is running
       Packet = xyGetParameter(Port, XY_GET_PACKET);
       if(Packet != LastPacket)
         {// show packet number
          printf(" P%1d",Packet);
          if(Packet%10==9) printf("\n");
         }
       LastPacket = Packet;
      }
   }
}

void main(int argc, char *argv[])
{int Code;
 int Port;
 int Baud;
 int Version;
 char *FileName;
 printf("_______________\n");
 printf("XMR 01/12/2000\n");

 //get command line arguments
 if(argc != 4)
   {printf("Usage: XMR <port> <baud> <FileName>\n");
    printf("   Eg: XMR 1 38400 myfile.dat\n");
    exit(1);
   }
 // get parameters
 Port = atoi(argv[1]) - 1;
 Baud = atoi(argv[2]);
 FileName = argv[3];
 printf("Port : COM%d\n",1+Port);
 printf("Baud : %1d\n",Baud);
 printf("File : %s\n",FileName);
 printf("_______________\n");
 // reset port (8N1 is default)
 Code = SioReset(Port,2048,2048);
 if(Code < 0)
   {SayError(Code, "SioReset");
    exit(1);
   }
 // set baud rate
 Code = SioBaud(Port,Baud);
 if(Code < 0)
   {SayError(Code, "SioBaud");
    exit(1);
   }
 // set DTR & RTS
 Code = SioDTR(Port,'S');
 Code = SioRTS(Port,'S');
 // set parms
 Code = SioParms(Port, WSC_NoParity, WSC_OneStopBit, WSC_WordLength8);
 // set RTS/CTS flow control
 SioFlow(Port,'H');
 // acquire xyDriver
 Code = xyAcquire(Port, Port);
 // show version number
 Version = xyGetParameter(Port,XY_GET_VERSION);
 printf("XYDRV Version %d.%d.%d\n", (Version>>8),0x0f&(Version>>4),0x0f&Version);
 // set EOF pad to blank
 Code = xySetParameter(Port, XY_SET_EOF_CHAR, 0x20);
 // set xyDriver debug level
 Code = xyDebug(DebugLevel);
 printf("Starting XMODEM receive (type Control-BREAK to quit)\n");
 Code = xyStartRx(Port, FileName, NAK, XMODEM);
 // run the XMODEM driver
 RunXY(Port);
 printf("\n");
 Code = xyRelease();
 Code = SioDone(Port);
}
